@@ -1,5 +1,5 @@
 /***************************************************************************
- * CVSID: $Id: osspec.c,v 1.52.2.5 2005/01/21 15:46:55 david Exp $
+ * CVSID: $Id: osspec.c,v 1.52.2.6 2005/03/28 19:15:19 david Exp $
  *
  * Detection and monitoring of devices on Linux 2.6 + udev
  *
@@ -1010,6 +1010,11 @@ add_device (const char *given_sysfs_path, const char *subsystem, struct hald_hel
 
 	strncpy (sysfs_path, given_sysfs_path, SYSFS_PATH_MAX);
 
+	if (hal_device_store_match_key_value_string (hald_get_gdl (), "linux.sysfs_path", sysfs_path)) {
+		HAL_WARNING (("devpath %s already present in the store, don't add device", sysfs_path));
+		return NULL;
+	}
+
 	len1 = snprintf (buf1, SYSFS_PATH_MAX, "%s/block", sysfs_mount_path);
 	len2 = snprintf (buf2, SYSFS_PATH_MAX, "%s/class", sysfs_mount_path);
 	if (strncmp (sysfs_path, buf1, len1) == 0 || strncmp (sysfs_path, buf2, len2) == 0) {
