@@ -1,5 +1,5 @@
 /***************************************************************************
- * CVSID: $Id: libhal-storage.c,v 1.8.2.4 2005/01/25 02:37:02 david Exp $
+ * CVSID: $Id: libhal-storage.c,v 1.8.2.5 2005/01/27 16:11:34 david Exp $
  *
  * libhal-storage.c : HAL convenience library for storage devices and volumes
  *
@@ -1510,7 +1510,12 @@ mopts_collect (LibHalContext *hal_ctx, const char *namespace, int namespace_len,
 
 					end = strchr (location, ',');
 					if (end == NULL) {
-						location[0] = '\0';
+						/* pointer arithmetic; uhh */
+						if (location > options_string) {
+							location[-1] = '\0'; /* uh, remove trailing comma */
+						} else {
+							location[0] = '\0';
+						}
 					} else {
 						strcpy (location, end + 1); /* skip the extra comma */
 					}
